statepath

package
v0.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 2, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package statepath provides helpers for resolving OSS state directory paths under the ~/.donmai/ directory.

Policy:

  • Canonical path is ~/.donmai/<file>
  • New writes always go to ~/.donmai/.
  • ~/Library/Logs/rensei/ is shared with the closed-source rensei binary and is NOT resolved here.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Resolve

func Resolve(suffix, tmpFallback string) string

Resolve returns the path to use for a state file under the ~/.donmai/ directory.

suffix is the path suffix under the state dir, e.g. "daemon.yaml".

tmpFallback is used when os.UserHomeDir() fails (e.g. in some test envs).

Types

This section is empty.

Jump to